# Simple A Stock Realtime Trade Mod
使用该Mod可以接收实时行情进行触发。用于 RQAlpha 实时模拟交易，实盘交易。

这个是一个初级的DEMO。

使用`--run-type`或者`-rt`为`p`(PaperTrading)，就可以激活改 mod。

```
rqalpha run -fq 1m -rt p -f ~/tmp/test_a.py -sc 100000 -l verbose
```
